# Security guidelines for fmu-datamodels
If you discover a security vulnerability in this project, please follow these steps to responsibly disclose it:

Do not create a public GitHub issue for the vulnerability.
Follow our guideline for Responsible Disclosure Policy at https://www.equinor.com/about-us/csirt to report the issue
The following information will help us triage your report more quickly:

Type of issue (e.g. buffer overflow, SQL injection, cross-site scripting, etc.)
Full paths of source file(s) related to the manifestation of the issue
The location of the affected source code (tag/branch/commit or direct URL)
Any special configuration required to reproduce the issue
Step-by-step instructions to reproduce the issue
Proof-of-concept or exploit code (if possible)
Impact of the issue, including how an attacker might exploit the issue

We prefer all communications to be in English.